function Pulse = HalfSinePulse( fsT )
% HalfSinePulse - pulse shape equal to half cycle of a sine
%
% Generate a pulse shaped like the positive half-cycle of a sine. This
% pulse is used in connection with OQPSK and is assumed to span TWO symbol
% periods.
%
% Input:
%   fsT - number of samples per symbol period
%
% Output:
%   Pulse - vector containing pulse
%
% Example:
%   Pulse = HalfSinePulse( fsT )
%
% See also:
%   OQPSK

%% generate pulse
tt    = (0:2*fsT-1)/fsT;
Pulse = sin(pi*tt/2);